CandidateInput
==============

.. currentmodule:: toasty.pipeline

.. autoclass:: CandidateInput
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CandidateInput.get_unique_id
      ~CandidateInput.save

   .. rubric:: Methods Documentation

   .. automethod:: get_unique_id
   .. automethod:: save
